@@ -260,8 +260,10 @@ class Log(object):
     def stop_active_tasks(self, log_dt: datetime):
         """Stop all active tasks by commiting changes to the logfile."""
         query_date = log_dt.date()
+        task_mask = self._log_df[wc.COL_CATEGORY] == wc.TOKEN_TASK
         date_mask = self._log_df["date"] == query_date
-        active_task_ids = get_active_task_ids(self._log_df[date_mask])
+        mask = task_mask & date_mask
+        active_task_ids = get_active_task_ids(self._log_df[mask])
         for task_id in active_task_ids:
             self._commit(wc.TOKEN_TASK, wc.TOKEN_STOP, log_dt, identifier=task_id)
 
@@ -360,7 +362,9 @@ class Log(object):
         # Test if there are running tasks
         if category == wc.TOKEN_SESSION:
             date_mask = self._log_df["date"] == log_dt.date()
-            active_tasks = get_active_task_ids(self._log_df[date_mask])
+            task_mask = self._log_df[wc.COL_CATEGORY] == wc.TOKEN_TASK
+            mask = date_mask & task_mask
+            active_tasks = get_active_task_ids(self._log_df[mask])
             if len(active_tasks) > 0:
                 if not force:
                     msg = self._err_msg_commit_active_tasks.format(
